@@ -6,6 +6,7 @@
 """
 
 
+from heapq import nlargest
 from operator import itemgetter
 from leafman.strategy import jaccard
 
@@ -39,9 +40,7 @@ def extract(suggestions, limit=5):
     :param suggestions: An iterable of suggestions.
     :param limit: Defaults to 5.
     """
-    return sorted(suggestions,
-                  key=itemgetter(1),
-                  reverse=1)[:limit]
+    return nlargest(limit, suggestions, key=itemgetter(1))
 
 
 def best_of(suggestions):
@@ -52,3 +51,23 @@ def best_of(suggestions):
     :param suggestions: An iterable of suggestions.
     """
     return max(suggestions, key=itemgetter(1))
+
+
+def relative_best(suggestions):
+    """
+    Returns the best suggestions relatively, that
+    is that their ranking equals or exceeds that of
+    the average ranking.
+
+    :param suggestions: The suggestions.
+    """
+    rv = []
+    runsum = 0
+    for choice, rank in suggestions:
+        rv.append((choice, rank))
+        runsum += rank
+
+    average = runsum / float(len(rv))
+    for choice, rank in rv:
+        if rank >= average:
+            yield choice, rank
